[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
Re: [Clanlib-devel] Doom de doom.
darn
I forgot the patch file itself !
stupid
Magnus Norddahl wrote:
Doomed! You are all doomed!
? config.guess
? config.sub
? depcomp
? install-sh
? ltmain.sh
? missing
? mkinstalldirs
? patch_get_wnd_sdl_and_dynamic_loading_module
? Examples/Library
? Examples/Joystick/joystick
? Sources/Application/Unix/.deps
? Sources/Application/Unix/.dirstamp
? Sources/Application/Unix/.libs
? Sources/Application/Unix/clanapp.lo
? Sources/Application/Win32/.deps
? Sources/Display/Providers/.deps
? Sources/Display/Providers/.dirstamp
? Sources/Display/Providers/.libs
? Sources/Display/Providers/jpeg_provider.lo
? Sources/Display/Providers/jpeg_provider_generic.lo
? Sources/Display/Providers/pcx_provider.lo
? Sources/Display/Providers/pcx_provider_generic.lo
? Sources/Display/Providers/png_provider.lo
? Sources/Display/Providers/png_provider_generic.lo
? Sources/Display/Providers/provider_factory.lo
? Sources/Display/Providers/provider_type.lo
? Sources/Display/Providers/targa_provider.lo
? Sources/Display/Providers/targa_provider_generic.lo
? Sources/Display/Win32/.deps
? Sources/Display/X11/.deps
? Sources/Display/X11/.dirstamp
? Sources/Display/X11/.libs
? Sources/Display/X11/font_x11.lo
? Sources/Display/X11/input_device_x11keyboard.lo
? Sources/Display/X11/input_device_x11mouse.lo
? Sources/GL/GLX/.deps
? Sources/GL/GLX/.dirstamp
? Sources/GL/GLX/.libs
? Sources/GL/GLX/display_window_opengl.lo
? Sources/GL/WGL/.deps
? Sources/Network/Browse/.deps
? Sources/Network/Browse/.dirstamp
? Sources/Network/Browse/.libs
? Sources/Network/Browse/browse_client.lo
? Sources/Network/Browse/browse_client_generic.lo
? Sources/Network/Browse/browse_master.lo
? Sources/Network/Browse/browse_master_generic.lo
? Sources/Network/Browse/browse_server.lo
? Sources/Network/Browse/browse_server_generic.lo
? Sources/Network/Browse/server_database.lo
? Sources/Network/IRC/.deps
? Sources/Network/IRC/.dirstamp
? Sources/Network/IRC/.libs
? Sources/Network/IRC/dcc_download.lo
? Sources/Network/IRC/dcc_download_generic.lo
? Sources/Network/IRC/irc_connection.lo
? Sources/Network/IRC/irc_connection_generic.lo
? Sources/Network/NetObjects/.deps
? Sources/Network/NetObjects/.dirstamp
? Sources/Network/NetObjects/.libs
? Sources/Network/NetObjects/netobject_client.lo
? Sources/Network/NetObjects/netobject_client_generic.lo
? Sources/Network/NetObjects/netobject_controller.lo
? Sources/Network/NetObjects/netobject_controller_generic.lo
? Sources/Network/NetObjects/netobject_server.lo
? Sources/Network/NetObjects/netobject_server_generic.lo
? Sources/Network/NetSession/.deps
? Sources/Network/NetSession/.dirstamp
? Sources/Network/NetSession/.libs
? Sources/Network/NetSession/inputsource_netpacket.lo
? Sources/Network/NetSession/inputsource_netpacket_generic.lo
? Sources/Network/NetSession/inputsource_netstream.lo
? Sources/Network/NetSession/netcomputer.lo
? Sources/Network/NetSession/netcomputer_generic.lo
? Sources/Network/NetSession/netgroup.lo
? Sources/Network/NetSession/netpacket.lo
? Sources/Network/NetSession/netpacket_generic.lo
? Sources/Network/NetSession/netsession.lo
? Sources/Network/NetSession/netsession_generic.lo
? Sources/Network/NetSession/netstream.lo
? Sources/Network/NetSession/netstream_generic.lo
? Sources/Network/NetSession/outputsource_netpacket.lo
? Sources/Network/NetSession/outputsource_netpacket_generic.lo
? Sources/Network/NetSession/outputsource_netstream.lo
? Sources/Network/NetVariables/.deps
? Sources/Network/NetVariables/.dirstamp
? Sources/Network/NetVariables/.libs
? Sources/Network/NetVariables/netvariables.lo
? Sources/Network/Socket/.deps
? Sources/Network/Socket/.dirstamp
? Sources/Network/Socket/.libs
? Sources/Network/Socket/event_trigger_socket.lo
? Sources/Network/Socket/inputsource_socket.lo
? Sources/Network/Socket/ip_address.lo
? Sources/Network/Socket/ip_address_getaddr.lo
? Sources/Network/Socket/ip_address_getsock.lo
? Sources/Network/Socket/outputsource_socket.lo
? Sources/Network/Socket/socket.lo
? Sources/Network/Socket/socket_generic.lo
? Sources/Network/Socket/socket_select.lo
? Sources/Sound/SoundFilters/.deps
? Sources/Sound/SoundFilters/.dirstamp
? Sources/Sound/SoundFilters/.libs
? Sources/Sound/SoundFilters/echofilter_generic.lo
? Sources/Sound/SoundFilters/fadefilter_generic.lo
? Sources/Sound/SoundFilters/inverse_echofilter_generic.lo
? Sources/Sound/SoundProviders/.deps
? Sources/Sound/SoundProviders/.dirstamp
? Sources/Sound/SoundProviders/.libs
? Sources/Sound/SoundProviders/soundprovider_factory.lo
? Sources/Sound/SoundProviders/soundprovider_raw.lo
? Sources/Sound/SoundProviders/soundprovider_raw_session.lo
? Sources/Sound/SoundProviders/soundprovider_recorder.lo
? Sources/Sound/SoundProviders/soundprovider_type.lo
? Sources/Sound/SoundProviders/soundprovider_wave.lo
? Sources/Sound/SoundProviders/soundprovider_wave_session.lo
? Sources/Sound/SoundProviders/Unix/.deps
? Sources/Sound/SoundProviders/Unix/.dirstamp
? Sources/Sound/SoundProviders/Unix/.libs
? Sources/Sound/SoundProviders/Unix/soundprovider_recorder_oss.lo
? Sources/Sound/SoundProviders/Win32/.deps
? Sources/Sound/Unix/.deps
? Sources/Sound/Unix/.dirstamp
? Sources/Sound/Unix/.libs
? Sources/Sound/Unix/soundoutput_oss.lo
? Sources/Sound/Win32/.deps
? Tests/GUITest/Intermediate
? Tests/GUITest/guitest
? Tests/ProviderTest/provider_test_gl
? Tests/ProviderTest/provider_test_sdl
? pkgconfig/Makefile
? pkgconfig/Makefile.in
Index: Makefile.am
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Makefile.am,v
retrieving revision 1.9
diff -u -r1.9 Makefile.am
--- Makefile.am 15 Sep 2003 19:15:57 -0000 1.9
+++ Makefile.am 29 Sep 2003 15:58:18 -0000
@@ -1,4 +1,4 @@
-SUBDIRS = Sources Setup Documentation pkgconfig
+SUBDIRS = Sources Setup pkgconfig
# EXAMPLE_SRC_PREFIX = $(datadir)/doc/ClanLib-docs-@version_minor@/Examples
Index: Sources/API/GL/opengl_window.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/API/GL/opengl_window.h,v
retrieving revision 1.10
diff -u -r1.10 opengl_window.h
--- Sources/API/GL/opengl_window.h 20 Jul 2003 22:36:26 -0000 1.10
+++ Sources/API/GL/opengl_window.h 29 Sep 2003 15:58:22 -0000
@@ -30,6 +30,8 @@
#ifdef WIN32
#include <wingdi.h>
+#else
+#include <X11/Xlib.h>
#endif
//: OpenGL top level window.
@@ -68,6 +70,9 @@
//: Returns the Win32 window handle.
HWND get_wnd();
+#else
+ //: Retuens the X11 display handle.
+ Display *get_wnd();
#endif
//! Operations:
Index: Sources/Core/System/Win32/cl_library.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/Core/System/Win32/cl_library.cpp,v
retrieving revision 1.2
diff -u -r1.2 cl_library.cpp
--- Sources/Core/System/Win32/cl_library.cpp 8 Sep 2003 08:07:44 -0000 1.2
+++ Sources/Core/System/Win32/cl_library.cpp 29 Sep 2003 15:58:24 -0000
@@ -62,8 +62,8 @@
if(adr == 0)
{
if(last_error != 0)
- delete last_error;
- last_error = new CL_Error("Couldn't find " + symbol + " within " + filename);
+ delete last_error;
+ last_error = new CL_Error(std::string("Couldn't find " + symbol + " within " + filename));
return 0;
}
@@ -77,7 +77,7 @@
{
if(last_error != 0)
delete last_error;
- last_error = new CL_Error("Couldn't load " + filename);
+ last_error = new CL_Error(std::string("Couldn't load " + filename));
loaded = false;
}
else
@@ -90,15 +90,19 @@
bool CL_LibraryLoader::unload()
{
+ if(last_error != 0)
+ {
+ delete last_error;
+ last_error = 0;
+ }
+
// Well if the handle is already NULL, don't need to unload it again
if(handle == 0)
return true;
if(FreeLibrary(handle) == 0)
{
- if(last_error != 0)
- delete last_error;
- last_error = new CL_Error("Couldn't unload " + filename);
+ last_error = new CL_Error(std::string("Couldn't unload " + filename));
return false;
}
@@ -110,6 +114,8 @@
CL_Error *CL_LibraryLoader::get_last_error() const
{
+ if(last_error == 0)
+ return new CL_Error("No CL_Library has been set");
return last_error;
}
Index: Sources/GL/opengl_window.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/GL/opengl_window.cpp,v
retrieving revision 1.8
diff -u -r1.8 opengl_window.cpp
--- Sources/GL/opengl_window.cpp 28 Aug 2003 14:42:24 -0000 1.8
+++ Sources/GL/opengl_window.cpp 29 Sep 2003 15:58:25 -0000
@@ -89,6 +89,12 @@
{
return gl_impl->get_hwnd();
}
+#else
+
+Display *CL_OpenGLWindow::get_wnd()
+{
+ return gl_impl->get_hwnd();
+}
#endif
Index: Sources/GL/surface_target_opengl.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/GL/surface_target_opengl.cpp,v
retrieving revision 1.4
diff -u -r1.4 surface_target_opengl.cpp
--- Sources/GL/surface_target_opengl.cpp 24 Sep 2003 18:26:57 -0000 1.4
+++ Sources/GL/surface_target_opengl.cpp 29 Sep 2003 15:58:26 -0000
@@ -291,7 +291,6 @@
translation.x *= attributes->scale_x;
translation.y *= attributes->scale_y;
-// CL_Rect tex_coords(0, 0, dest.get_width(), dest.get_height());
state.rotation_hotspot.x = dest.left-translation.x + state.rotation_hotspot.x * attributes->scale_x;
state.rotation_hotspot.y = dest.top-translation.y + state.rotation_hotspot.y * attributes->scale_y;
Index: Sources/GL/GLX/display_window_opengl.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/GL/GLX/display_window_opengl.cpp,v
retrieving revision 1.47
diff -u -r1.47 display_window_opengl.cpp
--- Sources/GL/GLX/display_window_opengl.cpp 14 Sep 2003 13:49:25 -0000 1.47
+++ Sources/GL/GLX/display_window_opengl.cpp 29 Sep 2003 15:58:26 -0000
@@ -111,6 +111,11 @@
return &gc;
}
+Display *CL_DisplayWindow_OpenGL::get_hwnd()
+{
+ return disp;
+}
+
CL_Size CL_DisplayWindow_OpenGL::get_max_surface_size() const
{
GLint max_texture_size;
Index: Sources/GL/GLX/display_window_opengl.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/GL/GLX/display_window_opengl.h,v
retrieving revision 1.24
diff -u -r1.24 display_window_opengl.h
--- Sources/GL/GLX/display_window_opengl.h 14 Sep 2003 13:49:25 -0000 1.24
+++ Sources/GL/GLX/display_window_opengl.h 29 Sep 2003 15:58:27 -0000
@@ -152,6 +152,9 @@
//: Called by ClanLib keep alive pump.
virtual void keep_alive();
+ //: Return the X display handle
+ virtual Display *get_hwnd();
+
//! Signals:
public:
//: Signal emitted when x11 events are to be processed.
Index: Sources/SDL/display_window_sdl.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/display_window_sdl.cpp,v
retrieving revision 1.9
diff -u -r1.9 display_window_sdl.cpp
--- Sources/SDL/display_window_sdl.cpp 16 Sep 2003 10:02:29 -0000 1.9
+++ Sources/SDL/display_window_sdl.cpp 29 Sep 2003 15:58:28 -0000
@@ -36,11 +36,7 @@
#include "API/Display/input_event.h"
#include <map>
-#ifdef WIN32
-#include <windows.h>
-#else
-#include <X11/keysym.h>
-#endif
+#include <SDL/SDL_syswm.h>
/////////////////////////////////////////////////////////////////////////////
// Construction:
@@ -297,3 +293,20 @@
{
}
+
+
+#ifdef WIN32
+HWND CL_DisplayWindow_SDL::get_wnd()
+{
+ SDL_SysWMinfo info;
+ SDL_GetWMInfo(&info);
+ return info.window;
+}
+#else
+Display *CL_DisplayWindow_SDL::get_wnd()
+{
+ SDL_SysWMinfo info;
+ SDL_GetWMInfo(&info);
+ return info.info.x11.display;
+}
+#endif
Index: Sources/SDL/display_window_sdl.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/display_window_sdl.h,v
retrieving revision 1.7
diff -u -r1.7 display_window_sdl.h
--- Sources/SDL/display_window_sdl.h 25 Aug 2003 09:09:42 -0000 1.7
+++ Sources/SDL/display_window_sdl.h 29 Sep 2003 15:58:29 -0000
@@ -35,7 +35,13 @@
#include "Display/display_window_generic.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
+
+#ifdef WIN32
+#include <windows.h>
+#else
+#include <X11/Xlib.h>
+#endif
class CL_DisplayWindow_SDL : public CL_DisplayWindow_Generic, CL_KeepAlive
{
@@ -86,6 +92,14 @@
//: Input device for the joystick.
CL_InputDevice joystick;
+#ifdef WIN32
+ //: Returns the Win32 window handle.
+ HWND get_wnd();
+#else
+ //: Returns the X11 window handle.
+ Display *get_wnd();
+#endif
+
//! Operations:
public:
//: Set window to fullscreen.
Index: Sources/SDL/graphic_context_sdl.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/graphic_context_sdl.cpp,v
retrieving revision 1.5
diff -u -r1.5 graphic_context_sdl.cpp
--- Sources/SDL/graphic_context_sdl.cpp 24 Aug 2003 16:49:29 -0000 1.5
+++ Sources/SDL/graphic_context_sdl.cpp 29 Sep 2003 15:58:29 -0000
@@ -27,7 +27,7 @@
#include "API/Core/System/log.h"
#include "API/Display/gradient.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
/////////////////////////////////////////////////////////////////////////////
// CL_GraphicContext_SDL construction:
Index: Sources/SDL/graphic_context_sdl.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/graphic_context_sdl.h,v
retrieving revision 1.3
diff -u -r1.3 graphic_context_sdl.h
--- Sources/SDL/graphic_context_sdl.h 24 Aug 2003 09:23:53 -0000 1.3
+++ Sources/SDL/graphic_context_sdl.h 29 Sep 2003 15:58:29 -0000
@@ -24,7 +24,7 @@
#include "Display/graphic_context_generic.h"
#include "API/signals.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
class CL_DisplayWindow_Generic;
Index: Sources/SDL/input_device_sdljoystick.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/input_device_sdljoystick.cpp,v
retrieving revision 1.3
diff -u -r1.3 input_device_sdljoystick.cpp
--- Sources/SDL/input_device_sdljoystick.cpp 25 Aug 2003 14:12:33 -0000 1.3
+++ Sources/SDL/input_device_sdljoystick.cpp 29 Sep 2003 15:58:30 -0000
@@ -29,7 +29,7 @@
#include "display_window_sdl.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
static int joystick_num = 0;
Index: Sources/SDL/input_device_sdljoystick.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/input_device_sdljoystick.h,v
retrieving revision 1.2
diff -u -r1.2 input_device_sdljoystick.h
--- Sources/SDL/input_device_sdljoystick.h 25 Aug 2003 09:09:42 -0000 1.2
+++ Sources/SDL/input_device_sdljoystick.h 29 Sep 2003 15:58:30 -0000
@@ -26,7 +26,7 @@
#include "API/signals.h"
#include "API/Core/Math/point.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
class CL_DisplayWindow_SDL;
Index: Sources/SDL/input_device_sdlkeyboard.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/input_device_sdlkeyboard.h,v
retrieving revision 1.3
diff -u -r1.3 input_device_sdlkeyboard.h
--- Sources/SDL/input_device_sdlkeyboard.h 24 Aug 2003 16:28:38 -0000 1.3
+++ Sources/SDL/input_device_sdlkeyboard.h 29 Sep 2003 15:58:30 -0000
@@ -25,7 +25,7 @@
#include "Display/input_device_generic.h"
#include "API/signals.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
class CL_DisplayWindow_SDL;
Index: Sources/SDL/input_device_sdlmouse.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/input_device_sdlmouse.h,v
retrieving revision 1.2
diff -u -r1.2 input_device_sdlmouse.h
--- Sources/SDL/input_device_sdlmouse.h 24 Aug 2003 16:28:38 -0000 1.2
+++ Sources/SDL/input_device_sdlmouse.h 29 Sep 2003 15:58:30 -0000
@@ -26,7 +26,7 @@
#include "API/signals.h"
#include "API/Core/Math/point.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
class CL_DisplayWindow_SDL;
Index: Sources/SDL/pixel_buffer_sdl_frame.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/pixel_buffer_sdl_frame.cpp,v
retrieving revision 1.2
diff -u -r1.2 pixel_buffer_sdl_frame.cpp
--- Sources/SDL/pixel_buffer_sdl_frame.cpp 23 Aug 2003 19:59:29 -0000 1.2
+++ Sources/SDL/pixel_buffer_sdl_frame.cpp 29 Sep 2003 15:58:30 -0000
@@ -24,7 +24,7 @@
#include "Display/graphic_context_generic.h"
#include "API/Core/System/error.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
/////////////////////////////////////////////////////////////////////////////
// CL_PixelBuffer_SDL_Frame construction:
Index: Sources/SDL/surface_sdl.h
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/SDL/surface_sdl.h,v
retrieving revision 1.4
diff -u -r1.4 surface_sdl.h
--- Sources/SDL/surface_sdl.h 30 Aug 2003 13:38:01 -0000 1.4
+++ Sources/SDL/surface_sdl.h 29 Sep 2003 15:58:30 -0000
@@ -27,7 +27,7 @@
#include "API/Display/surface.h"
#include "API/Core/Math/size.h"
-#include "SDL.h"
+#include <SDL/SDL.h>
class CL_Surface_SDL : public CL_Surface_Target
{
_______________________________________________
Clanlib-devel mailing list
Clanlib-devel@clanlib.org
http://clanlib.org/mailman/listinfo/clanlib-devel
Index: Sources/Core/System/Unix/cl_library.cpp
===================================================================
RCS file: /var/lib/cvs/Libs/ClanLib-0.7/Sources/Core/System/Unix/cl_library.cpp,v
retrieving revision 1.2
diff -u -r1.2 cl_library.cpp
--- Sources/Core/System/Unix/cl_library.cpp 8 Sep 2003 15:08:51 -0000 1.2
+++ Sources/Core/System/Unix/cl_library.cpp 29 Sep 2003 15:58:24 -0000
@@ -23,10 +23,12 @@
#include "Core/precomp.h"
#include "API/Core/System/cl_library.h"
-#ifdef USE_DLFUNC
+#ifdef USE_DYN
#include <dlfcn.h>
#endif
+#include <iostream>
+
std::map<std::string, CL_LibraryFactoryMaker *, std::less<std::string> > CL_LibraryManager::libraries;
CL_LibraryLoader::CL_LibraryLoader(const std::string& file) : filename(file), loaded(false), handle(0), last_error(0)
@@ -57,7 +59,7 @@
void *CL_LibraryLoader::resolve(const std::string& symbol)
{
-#ifdef USE_DLFUNC
+#ifdef USE_DYN
// Just in case the handle has been corrupted
if(handle == 0)
return 0;
@@ -71,11 +73,14 @@
{
if(last_error != 0)
delete last_error;
- last_error = new CL_Error(error);
+ last_error = new CL_Error(std::string(error));
return 0;
}
#else
void *adr = 0;
+ if(last_error != 0)
+ delete last_error;
+ last_error = new CL_Error(std::string("ClanLib hasn't been built with dynamic loading support"));
#endif
return adr;
@@ -83,14 +88,20 @@
bool CL_LibraryLoader::load()
{
-#ifdef USE_DLFUNC
- // We use RTLD_LAZY which is a good default nowadays
- handle = dlopen(filename.c_str(), RTLD_LAZY);
+#ifdef USE_DYN
+ // We use RTLD_LAZY|RTLD_GLOBAL which is a good default nowadays
+ handle = dlopen(filename.c_str(), RTLD_LAZY|RTLD_GLOBAL);
if(handle == 0)
{
- if(last_error != 0)
- delete last_error;
- last_error = new CL_Error(dlerror());
+ const char *error = dlerror();
+ // If the error is not NULL, then the dlopen call failed
+ if(error != 0)
+ {
+ if(last_error != 0)
+ delete last_error;
+ last_error = new CL_Error(std::string(error));
+
+ }
loaded = false;
}
else
@@ -99,6 +110,9 @@
}
#else
loaded = false;
+ if(last_error != 0)
+ delete last_error;
+ last_error = new CL_Error(std::string("ClanLib hasn't been built with dynamic loading support"));
#endif
return loaded;
@@ -106,16 +120,20 @@
bool CL_LibraryLoader::unload()
{
-#ifdef USE_DLFUNC
+#ifdef USE_DYN
+ if(last_error != 0)
+ {
+ delete last_error;
+ last_error = 0;
+ }
+
// Well if the handle is already NULL, don't need to unload it again
if(handle == 0)
return true;
if(dlclose(handle) != 0)
{
- if(last_error != 0)
- delete last_error;
- last_error = new CL_Error(dlerror());
+ last_error = new CL_Error(std::string(dlerror()));
return false;
}
@@ -128,6 +146,8 @@
CL_Error *CL_LibraryLoader::get_last_error() const
{
+ if(last_error == 0)
+ return new CL_Error(std::string("No CL_Library error set so far"));
return last_error;
}